@@ -19,6 +19,7 @@ __all__ = ['Timeline']
 __metaclass__ = type
 
 import datetime
+import sys
 import traceback
 
 from pytz import utc as UTC
@@ -45,6 +46,14 @@ class OverlappingActionError(Exception):
     # do an actual stacked/tree model of actions - if needed.
 
 
+def format_stack():
+    """Format a stack like traceback.format_stack, but skip 2 frames.
+
+    This means the stack formatting frame isn't in the backtrace itself.
+    """
+    return traceback.format_stack(f=sys._getframe(2))
+
+
 class Timeline:
     """A sequence of TimedActions.
 
@@ -55,7 +64,7 @@ class Timeline:
     :ivar baseline: The point the timeline starts at.
     """
 
-    def __init__(self, actions=None, format_stack=traceback.format_stack):
+    def __init__(self, actions=None, format_stack=format_stack):
         """Create a Timeline.
         
         :param actions: An optional object to use to store the timeline. This
